@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: connection.c 1508 2007-05-16 14:42:08Z guus $
+    $Id: connection.c 1600 2008-12-23 23:14:37Z guus $
 */
 
 #include "system.h"
@@ -90,12 +90,31 @@ void free_connection(connection_t *c)
 	if(c->outkey)
 		free(c->outkey);
 
+	if(c->inctx) {
+		EVP_CIPHER_CTX_cleanup(c->inctx);
+		free(c->inctx);
+	}
+
+	if(c->outctx) {
+		EVP_CIPHER_CTX_cleanup(c->outctx);
+		free(c->outctx);
+	}
+
 	if(c->mychallenge)
 		free(c->mychallenge);
 
 	if(c->hischallenge)
 		free(c->hischallenge);
 
+	if(c->config_tree)
+		exit_configuration(&c->config_tree);
+
+	if(c->outbuf)
+		free(c->outbuf);
+
+	if(c->rsa_key)
+		RSA_free(c->rsa_key);
+
 	free(c);
 }
 
