@@ -1,7 +1,7 @@
 /*
     protocol.c -- handle the meta-protocol, basic functions
-    Copyright (C) 1999-2005 Ivo Timmermans <ivo@tinc-vpn.org>,
-                  2000-2005 Guus Sliepen <guus@tinc-vpn.org>
+    Copyright (C) 1999-2005 Ivo Timmermans,
+                  2000-2006 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: protocol.c 1439 2005-05-04 18:09:30Z guus $
+    $Id: protocol.c 1452 2006-04-26 13:52:58Z guus $
 */
 
 #include "system.h"
@@ -241,7 +241,7 @@ void age_past_requests(void)
 		next = node->next;
 		p = node->data;
 
-		if(p->firstseen + pingtimeout < now)
+		if(p->firstseen + pinginterval < now)
 			avl_delete_node(past_request_tree, node), deleted++;
 		else
 			left++;
